@@ -11,7 +11,8 @@ from tempfile import TemporaryDirectory
 
 from traitlets import Bool, Instance, Integer, List, Unicode, default
 
-from ..utils import _contextlib_chdir
+from nbconvert.utils import _contextlib_chdir
+
 from .latex import LatexExporter
 
 
@@ -22,12 +23,15 @@ class LatexFailed(IOError):  # noqa
     """
 
     def __init__(self, output):
+        """Initialize the error."""
         self.output = output
 
     def __unicode__(self):
+        """Unicode representation."""
         return "PDF creating failed, captured latex output:\n%s" % self.output
 
     def __str__(self):
+        """String representation."""
         u = self.__unicode__()
         return u
 
@@ -80,7 +84,9 @@ class PDFExporter(LatexExporter):
     def _template_extension_default(self):
         return ".tex.j2"
 
-    def run_command(self, command_list, filename, count, log_function, raise_on_failure=None):
+    def run_command(  # noqa
+        self, command_list, filename, count, log_function, raise_on_failure=None
+    ):
         """Run command_list count times.
 
         Parameters
@@ -108,18 +114,19 @@ class PDFExporter(LatexExporter):
         cmd = shutil.which(command_list[0])
         if cmd is None:
             link = "https://nbconvert.readthedocs.io/en/latest/install.html#installing-tex"
-            raise OSError(
+            msg = (
                 "{formatter} not found on PATH, if you have not installed "
                 "{formatter} you may need to do so. Find further instructions "
                 "at {link}.".format(formatter=command_list[0], link=link)
             )
+            raise OSError(msg)
 
         times = "time" if count == 1 else "times"
         self.log.info("Running %s %i %s: %s", command_list[0], count, times, command)
 
         shell = sys.platform == "win32"
         if shell:
-            command = subprocess.list2cmdline(command)
+            command = subprocess.list2cmdline(command)  # type:ignore
         env = os.environ.copy()
         prepend_to_env_search_path("TEXINPUTS", self.texinputs, env)
         prepend_to_env_search_path("BIBINPUTS", self.texinputs, env)
@@ -138,20 +145,17 @@ class PDFExporter(LatexExporter):
                 )
                 out, _ = p.communicate()
                 if p.returncode:
-                    if self.verbose:
+                    if self.verbose:  # noqa
                         # verbose means I didn't capture stdout with PIPE,
                         # so it's already been displayed and `out` is None.
-                        out = ""
+                        out_str = ""
                     else:
-                        out = out.decode("utf-8", "replace")
+                        out_str = out.decode("utf-8", "replace")
                     log_function(command, out)
-                    self._captured_output.append(out)
+                    self._captured_output.append(out_str)
                     if raise_on_failure:
-                        raise raise_on_failure(
-                            'Failed to run "{command}" command:\n{output}'.format(
-                                command=command, output=out
-                            )
-                        )
+                        msg = f'Failed to run "{command}" command:\n{out_str}'
+                        raise raise_on_failure(msg)
                     return False  # failure
         return True  # success
 
@@ -178,6 +182,7 @@ class PDFExporter(LatexExporter):
         return self.run_command(self.bib_command, filename, 1, log_error, raise_on_failure)
 
     def from_notebook_node(self, nb, resources=None, **kw):
+        """Convert from notebook node."""
         latex, resources = super().from_notebook_node(nb, resources=resources, **kw)
         # set texinputs directory, so that local files will be found
         if resources and resources.get("metadata", {}).get("path"):
