@@ -9,6 +9,7 @@ that uses Jinja2 to export notebook files into different formats.
 import html
 import json
 import os
+import typing as t
 import uuid
 import warnings
 from pathlib import Path
@@ -22,6 +23,7 @@ from jinja2 import (
     TemplateNotFound,
 )
 from jupyter_core.paths import jupyter_path
+from nbformat import NotebookNode
 from traitlets import Bool, Dict, HasTraits, List, Unicode, default, observe, validate
 from traitlets.config import Config
 from traitlets.utils.importstring import import_item
@@ -101,6 +103,7 @@ def recursive_update(target, new):
 
 # define function at the top level to avoid pickle errors
 def deprecated(msg):
+    """Emit a deprecation warning."""
     warnings.warn(msg, DeprecationWarning)
 
 
@@ -114,10 +117,12 @@ class ExtensionTolerantLoader(BaseLoader):
     """
 
     def __init__(self, loader, extension):
+        """Initialize the loader."""
         self.loader = loader
         self.extension = extension
 
     def get_source(self, environment, template):
+        """Get the source for a template."""
         try:
             return self.loader.get_source(environment, template)
         except TemplateNotFound:
@@ -126,6 +131,7 @@ class ExtensionTolerantLoader(BaseLoader):
             return self.loader.get_source(environment, template + self.extension)
 
     def list_templates(self):
+        """List available templates."""
         return self.loader.list_templates()
 
 
@@ -144,7 +150,7 @@ class TemplateExporter(Exporter):
     """
 
     # finish the docstring
-    __doc__ = __doc__.format(filters="- " + "\n    - ".join(sorted(default_filters.keys())))
+    __doc__ = __doc__.format(filters="- " + "\n    - ".join(sorted(default_filters.keys())))  # noqa
 
     _template_cached = None
 
@@ -208,23 +214,22 @@ class TemplateExporter(Exporter):
             directory, self.template_file = os.path.split(self.template_name)
             if directory:
                 directory, template_name = os.path.split(directory)
-            if directory:
-                if os.path.isabs(directory):
-                    self.extra_template_basedirs = [directory]
+            if directory and os.path.isabs(directory):
+                self.extra_template_basedirs = [directory]
         return template_name
 
     @observe("template_file")
     def _template_file_changed(self, change):
         new = change["new"]
         if new == "default":
-            self.template_file = self.default_template
+            self.template_file = self.default_template  # type:ignore
             return
         # check if template_file is a file path
         # rather than a name already on template_path
         full_path = os.path.abspath(new)
         if os.path.isfile(full_path):
             directory, self.template_file = os.path.split(full_path)
-            self.extra_template_paths = [directory] + self.extra_template_paths
+            self.extra_template_paths = [directory, *self.extra_template_paths]
             # While not strictly an invalid template file name, the extension hints that there isn't a template directory involved
             if self.template_file.endswith(".tpl"):
                 warnings.warn(
@@ -360,7 +365,8 @@ class TemplateExporter(Exporter):
                 self.template_file = self._raw_template_key
 
         if not self.template_file:
-            raise ValueError("No template_file specified!")
+            msg = "No template_file specified!"
+            raise ValueError(msg)
 
         # First try to load the
         # template by name with extension added, then try loading the template
@@ -370,7 +376,21 @@ class TemplateExporter(Exporter):
         self.log.debug("    template_paths: %s", os.pathsep.join(self.template_paths))
         return self.environment.get_template(template_file)
 
-    def from_notebook_node(self, nb, resources=None, **kw):
+    def from_filename(  # type:ignore
+        self, filename: str, resources: t.Optional[dict] = None, **kw: t.Any
+    ) -> t.Tuple[str, dict]:
+        """Convert a notebook from a filename."""
+        return super().from_filename(filename, resources, **kw)  # type:ignore
+
+    def from_file(  # type:ignore
+        self, file_stream: t.Any, resources: t.Optional[dict] = None, **kw: t.Any
+    ) -> t.Tuple[str, dict]:
+        """Convert a notebook from a file."""
+        return super().from_file(file_stream, resources, **kw)  # type:ignore
+
+    def from_notebook_node(  # type:ignore
+        self, nb: NotebookNode, resources: t.Optional[dict] = None, **kw: t.Any
+    ) -> t.Tuple[str, dict]:
         """
         Convert a notebook from a notebook node instance.
 
@@ -415,7 +435,8 @@ class TemplateExporter(Exporter):
         filter : filter
         """
         if jinja_filter is None:
-            raise TypeError("filter")
+            msg = "filter"
+            raise TypeError(msg)
         isclass = isinstance(jinja_filter, type)
         constructed = not isclass
 
@@ -445,7 +466,8 @@ class TemplateExporter(Exporter):
         else:
             # filter is an instance of something without a __call__
             # attribute.
-            raise TypeError("filter")
+            msg = "filter"
+            raise TypeError(msg)
 
     def register_filter(self, name, jinja_filter):
         """
@@ -480,11 +502,12 @@ class TemplateExporter(Exporter):
         paths = self.template_paths
         self.log.debug("Template paths:\n\t%s", "\n\t".join(paths))
 
-        loaders = self.extra_loaders + [
+        loaders = [
+            *self.extra_loaders,
             ExtensionTolerantLoader(FileSystemLoader(paths), self.template_extension),
             DictLoader({self._raw_template_key: self.raw_template}),
         ]
-        environment = Environment(
+        environment = Environment(  # noqa
             loader=ChoiceLoader(loaders),
             extensions=JINJA_EXTENSIONS,
             enable_async=self.enable_async,
@@ -511,18 +534,18 @@ class TemplateExporter(Exporter):
         #  * We rely on recursive_update, which can only merge dicts, lists will be overwritten
         #  * We can use the key with numerical prefixing to guarantee ordering (/etc/*.d/XY-file style)
         #  * We can disable preprocessors by overwriting the value with None
-        for _, preprocessor in sorted(preprocessors.items(), key=lambda x: x[0]):
+        for _, preprocessor in sorted(preprocessors.items(), key=lambda x: x[0]):  # type:ignore
             if preprocessor is not None:
                 kwargs = preprocessor.copy()
                 preprocessor_cls = kwargs.pop("type")
                 preprocessor_cls = import_item(preprocessor_cls)
                 if preprocessor_cls.__name__ in self.config:
                     kwargs.update(self.config[preprocessor_cls.__name__])
-                preprocessor = preprocessor_cls(**kwargs)
+                preprocessor = preprocessor_cls(**kwargs)  # noqa
                 self.register_preprocessor(preprocessor)
 
     def _get_conf(self):
-        conf = {}  # the configuration once all conf files are merged
+        conf: dict = {}  # the configuration once all conf files are merged
         for path in map(Path, self.template_paths):
             conf_path = path / "conf.json"
             if conf_path.exists():
@@ -567,6 +590,7 @@ class TemplateExporter(Exporter):
 
     @classmethod
     def get_compatibility_base_template_conf(cls, name):
+        """Get the base template config."""
         # Hard-coded base template confs to use for backwards compatibility for 5.x-only templates
         if name == "display_priority":
             return {"base_template": "base"}
@@ -574,14 +598,14 @@ class TemplateExporter(Exporter):
             return {"base_template": "classic", "mimetypes": {"text/html": True}}
 
     def get_template_names(self):
-        # finds a list of template names where each successive template name is the base template
+        """Finds a list of template names where each successive template name is the base template"""
         template_names = []
         root_dirs = self.get_prefix_root_dirs()
         base_template = self.template_name
-        merged_conf = {}  # the configuration once all conf files are merged
+        merged_conf: dict = {}  # the configuration once all conf files are merged
         while base_template is not None:
             template_names.append(base_template)
-            conf = {}
+            conf: dict = {}
             found_at_least_one = False
             for base_dir in self.extra_template_basedirs:
                 template_dir = os.path.join(base_dir, base_template)
@@ -635,6 +659,7 @@ class TemplateExporter(Exporter):
         return template_names
 
     def get_prefix_root_dirs(self):
+        """Get the prefix root dirs."""
         # We look at the usual jupyter locations, and for development purposes also
         # relative to the package directory (first entry, meaning with highest precedence)
         root_dirs = []
