@@ -130,7 +130,7 @@ class Highlight2Latex(NbConvertBase):
             source, LatexFormatter(**self.extra_formatter_options), language, metadata
         )
         if strip_verbatim:
-            latex = latex.replace(r"\begin{Verbatim}[commandchars=\\\{\}]" + "\n", "")
+            latex = latex.replace(r"\begin{Verbatim}[commandchars=\\\{\}]" + "\n", "")  # noqa
             return latex.replace("\n\\end{Verbatim}\n", "")
         else:
             return latex
@@ -157,7 +157,6 @@ def _pygments_highlight(source, output_formatter, language="ipython", metadata=N
     # If the cell uses a magic extension language,
     # use the magic language instead.
     if language.startswith("ipython") and metadata and "magics_language" in metadata:
-
         language = metadata["magics_language"]
 
     lexer = None
