@@ -7,6 +7,8 @@ import warnings
 from bleach import ALLOWED_ATTRIBUTES, ALLOWED_TAGS, clean
 from traitlets import Any, Bool, List, Set, Unicode
 
+from .base import Preprocessor
+
 _USE_BLEACH_CSS_SANITIZER = False
 _USE_BLEACH_STYLES = False
 
@@ -38,8 +40,6 @@ except ImportError:
         )
 
 
-from .base import Preprocessor
-
 __all__ = ["SanitizeHTML"]
 
 
@@ -109,7 +109,7 @@ class SanitizeHTML(Preprocessor):
           code:
             Sanitize outputs that could result in code execution
         """
-        if cell.cell_type == "raw":
+        if cell.cell_type == "raw":  # noqa
             # Sanitize all raw cells anyway.
             # Only ones with the text/html mimetype should be emitted
             # but erring on the side of safety maybe.
